/*
+-------+-----------------+------+-----------------+-------+-----------------+
|Program| BASENAME.C      |Header| HANSOFT         |Library| HANSOFT         |
+-------+-----------------+------+-----------------+-------+----------+------+
|HISTORY                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| Turbo C V2.0 version                             | HanSoft          |190591|
| Bull DPX/2 version                               | HanSoft          |240792|
| Linux 2.2.14 version                             | HanSoft          |190800|
+--------------------------------------------------+------------------+------+
|MODIFICATION LOG                                  |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| Added check for filenames with only drivespecs   | HanSoft          |200591|
| Made the routine portable to Unix                | HanSoft          |240792|
| Added manual page support                        | HanSoft          |250993|
| Added ANSI_C support                             | HanSoft          |280294|
| Made function ANSI-C compliant                   | HanSoft          |190800|
+--------------------------------------------------+------------------+------+
|REMARKS                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| None                                             |                  |      |
+--------------------------------------------------+------------------+------+

  Copyright (C) 1991,2002 J.L. Bezemer

  This file is part of BDDE

  BDDE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


Strips a given full filename from its path and returns the bare filename. Does
not check if it is a valid filename.

Prototype: char *basename (char *fullname)
Returns  : (char *) to filename part of str
Memory   : None allocated
Example  :

#include <stdio.h>

void main (void)
{
  char str1 [32] = "c:\\users9\\c\\test.c";
  char str2 [32] = "c:\\users5\\arj\\extlib.arj";

  puts (basename (str1));
  puts (basename (str2));
}

Input    : None
Output   : test.c
           extlib.arj
Related  : dirname()
Primitive: Yes
*/

#include <stddef.h>
#include <string.h>

#ifdef UNIX
#define _DS_ '/'
#else
#define _DS_ '\\'
#endif

#ifndef ARCHAIC
  char *basename (char *full_name)
#else
  char *basename (full_name) char *full_name;
#endif

{
  char *p = strrchr (full_name, _DS_);
#ifndef UNIX
  if (p == NULL) p = strrchr (full_name, ':');
#endif
  return (p == NULL ? full_name : ++p);
}

