/*       bddelib.h

  Copyright (C) 1991,2002 J.L. Bezemer

  This file is part of BDDE

  BDDE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


/*
These string functions only depend on standard C functions and not on other
functions included here. So they are called 'primitives'.
*/

#include "strslc.c"
#include "strncopy.c"
#include "strchrc.c"
#include "strlchr.c"
#include "strcalc.c"
#include "strpos.c"

/*
These string functions depend on previously defined string functions, so
they are called 'complex'. Don't change the order of inclusion or you're
in trouble. You shouldn't have to change anything here.
*/

#include "fload.c"
#include "strtodir.c"
#include "strtova.c"
#include "strtrm.c"

/*
These are portable C functions. The dirname() function is only used in the
MS-DOS version. You shouldn't have to change anything here. If your Unix
C-compiler does not contain a strlwr() function, all is OK. If it does, you
should remove the two #else..strlwr.c lines.
*/

#include "basename.c"
#ifndef UNIX
#include "dirname.c"
#endif
#ifndef __TURBOC__
#include "strnicmp.c"
#include "strlwr.c"
#endif


/*
This #include takes care of all extentions that are build on top
of all FILE* functions. Thus "stdio.h" must have been included
before they can be included.  Those functions are part of the
Portable C EXTentions, with all prototypes in "pcext.h". Since
this library is not a part of this program an interface has to be
provided. Please check your own compiler to see if the #define is
right. If your compiler uses a different #define (like __STDIO)
you might have to change this to make it work.
*/

#ifndef UNIX
#if !defined(__STDIO_DEF_)
#include <stdio.h>
#endif
#else
#if !defined(_STDIO_H)
#include <stdio.h>
#endif
#endif

/*
This is to prevent compile errors due to the fact that BUFSIZ has not been
defined. It should have been defined in <stdio.h>. It assignes values to
BUFSIZ that are probably not be too far away from the actual value for that
particular Operating System. You shouldn't have to change anything here.
*/

#ifndef BUFSIZ
#ifndef UNIX
#define BUFSIZ 512
#else
#define BUFSIZ 1024
#endif
#endif

/*
These functions depend heavily on <stdio.h> since they are file manipulation
extensions. You shouldn't have to change anything here.
*/

#include "fget_va.c"
#include "free_va.c"
#include "depth_va.c"

/*
This include redefines access() by using an macro-definition.
Please check your own compiler to see if the #define is right.
If your compiler uses a different #define (like _UNIX_IO) you might
have to change this to make it work.
*/

#ifndef UNIX
#if !defined(_IO_H)
#include <io.h>
#endif
#else
#if !defined(_UNISTD_H)
#include <unistd.h>
#endif
#endif

#define exists(a) (!(access(a,0)))
