/*
+-------+-----------------+------+-----------------+-------+-----------------+
|Program| FGET_VA.C       |Header| HANSOFT.H       |Library| HANSOFT         |
+-------+-----------------+------+-----------------+-------+----------+------+
|HISTORY                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| TurboC V2.0 version                              | HanSoft          |230591|
| Bull DPX/2 version                               | HanSoft          |170792|
+--------------------------------------------------+------------------+------+
|MODIFICATION LOG                                  |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| Check on '\n' added, gets() call corrected       | HanSoft          |280591|
| Truncation routine added                         | HanSoft          |280591|
| Major bug fixed: unable to recover from realloc()| HanSoft          |290591|
| Completely rewritten to N. Keeman standards      | HanSoft          |290292|
| Now returns NULL pointer on error                | HanSoft          |030392|
| Returns NULL on file-error; fopene() removed     | HanSoft          |020492|
| Added #include <stdio.h>                         | HanSoft          |230492|
| Added mode-argument                              | HanSoft          |280492|
| Rewrote most of fget_va(); deleted mode-argument | HanSoft          |060993|
| Added ANSI_C and CEXT support                    | HanSoft          |280294|
| Added support for fload()                        | HanSoft          |270196|
| Fixed incorrect factoring                        | HanSoft          |300196|
| Made function ANSI-C compliant                   | HanSoft          |260697|
+--------------------------------------------------+------------------+------+
|REMARKS                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| None                                             |                  |      |
+--------------------------------------------------+------------------+------+

  Copyright (C) 1991,2002 J.L. Bezemer

  This file is part of BDDE

  BDDE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


Returns a pointer to an variable array containing the lines of file TFname.
Returns NULL-pointer on error. File cannot be larger than 64K under DOS.
Empty lines are discarded. No Buffering available.

Prototype: char **Fget_va (char* TFname, char *delims)
Returns  : Pointer to variable array on success; else NULL
Memory   : Size of the file plus the pointer array to the lines
Example  :

#include <stdio.h>

int main (int argc, char **argv)

{
  char **Va;

  if ((Va = Fget_va ("data.txt", "\r\n")) == NULL) puts ("Data error");
  else for (;*Va; Va++) puts (*Va);

  return (EXIT_SUCCESS);
}

Input    : None
Output   : depends on machine
Related  : Fput_va(), Fgetb_va()
*/


#ifdef UNIX
#include <sys/types.h>
#endif
#ifdef USRLIBHANSOFT
#include <hansoft.h>
#else
#include "hansoft.h"
#endif
#include <stdlib.h>


#ifndef ARCHAIC
  char **Fget_va (char* Fname, char* delims)
#else
  char **Fget_va (Fname, delims) char *Fname; char *delims;
#endif

{
  size_t        Fsize;                 /* size of file */
  char         *Fimage;
  char        **Fp_va;                 /* lines list (pointers) */

  if ((Fimage = Fload (Fname, 1, &Fsize)) == NULL) return (NULL);
  else
     {
       Fimage [(unsigned) Fsize] = '\0';
       if ((Fp_va = Strtova (Fimage, delims)) != NULL) return (Fp_va);
     }

  free (Fimage);
  return (NULL);
}
