/*
+-------+-----------------+------+-----------------+-------+-----------------+
|Program| FLOAD.C         |Header| HANSOFT.H       |Library| HANSOFT         |
+-------+-----------------+------+-----------------+-------+----------+------+
|HISTORY                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| TurboC V2.0 version                              | HanSoft          |270196|
+--------------------------------------------------+------------------+------+
|MODIFICATION LOG                                  |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| Rewrote function and changed to normal C         | HanSoft          |070198|
| Rewrote function to pure ANSI-C                  | Reuben Thomas    |210799|
| Cleaned up the code a little                     | HanSoft          |150999|
| Made constants long                              | HanSoft          |111199|
| Fixed small Linux error (and optimized)          | HanSoft          |210301|
+--------------------------------------------------+------------------+------+
|REMARKS                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| None                                             |                  |      |
+--------------------------------------------------+------------------+------+

  Copyright (C) 1996,2001 J.L. Bezemer

  This file is part of HanSoft Extended Library

  Extended Library is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


Returns a pointer to a character array containing file TFname. Allocates
TFxtra number of bytes at the end of the file. TFsize will contain the number
of bytes in the file (not including TFxtra). Returns NULL-pointer on error.
File cannot be larger than 64K under DOS. No Buffering available.

Prototype: char *Fload (char* TFname, size_t TFxtra, size_t *TFsize)
Returns  : Pointer to character array on success; else NULL
Memory   : Size of the file plus the extra bytes allocated
Example  :

#include <stdio.h>

int main (void)

{
  char *FileContents;

  if ((FileContents = fload ("data.txt", 1, &Fsize)) == NULL)
     puts ("Data error");
  else for (;*FileContents; FileContents++) puts (*FileContents);

  return (0);
}

Input    : None
Output   : depends on machine
Related  : Fget_va(), Fgetb_va()
*/


#ifdef UNIX
#include <sys/types.h>
#endif
#include <stdlib.h>
#include <stdio.h>


#ifndef ARCHAIC
  char *Fload (char* TFname, size_t TFxtra, size_t *TFsize)
#else
  char *Fload (TFname, TFxtra, TFsize) char *TFname; size_t TFxtra;
       size_t *TFsize;
#endif

{
  char *TFbuf = NULL;                  /* buffer that holds file */
  FILE *TFile;                         /* file pointer to textfile */
  long  Ext;                           /* length of file */
                                       /* open file and get size */
  if ((TFile = fopen (TFname, "rb")) != NULL)
     if (! fseek (TFile, 0L, SEEK_END))
        if ((Ext = ftell (TFile)) != -1L)
           if (! fseek (TFile, 0L, SEEK_SET))
              if ((TFbuf = (char *) calloc (((*TFsize = (size_t) Ext) +
                 TFxtra), sizeof (char))) != NULL)
                                       /* now read the contents */
                 if (fread (TFbuf, sizeof (char), *TFsize, TFile) == *TFsize)
                    {                  /* if ok, return buffer */
                      if (! fclose (TFile)) return (TFbuf); 
                      else TFile = NULL;
                    }                  /* prevent second closing */

  if (TFbuf) free   (TFbuf);           /* if allocated, free space */
  if (TFile) fclose (TFile);           /* if file opened, close file */
  return (NULL);
}
