/*
+-------+-----------------+------+-----------------+-------+-----------------+
|Program| STRTOVA         |Header| HANSOFT         |Library| HANSOFT         |
+-------+-----------------+------+-----------------+-------+----------+------+
|HISTORY                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| TurboC V2.0 version                              | HanSoft          |211189|
| DPX/2 version                                    | HanSoft          |160491|
+--------------------------------------------------+------------------+------+
|MODIFICATION LOG                                  |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| New way to allocate memory, new parameters       | HanSoft          |110290|
| Changed includes to enhance portability          | HanSoft          |160491|
| Reallocation removed                             | HanSoft          |250292|
| Added manual page support                        | HanSoft          |210792|
| Added better documentation                       | HanSoft          |260893|
| Added ANSI_C and CEXT support                    | HanSoft          |280294|
| Made function ANSI-C compliant                   | HanSoft          |260698|
+--------------------------------------------------+------------------+------+
|REMARKS                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| None                                             |                  |      |
+--------------------------------------------------+------------------+------+

  Copyright (C) 1991,2002 J.L. Bezemer

  This file is part of BDDE

  BDDE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

  
This function tokenizes a string into an array of pointers to string and
returns a pointer to it. All delimiters are removed. The original string is
altered.

Prototype: char **Strtova (char *str, char *delimit)
Returns  : Pointer (char**) on success; NULL-pointer on error
Memory   : sizeof (*char) * (strchrc () + 2)
Example  :

#include <stdio.h>
#include "hansoft.h"
#include <stdlib.h>


int main (int argc, char **argv)

{
  char **words;
  char **p;

  words = Strtova ("Error: not installed", " ,.!?;:\t");

  if (words)
     for (p = words ; *p; p++) puts (*p);
  else puts ("Error in call to Strtova()");

  free (words);
  return (EXIT_SUCCESS);
}

Input    : None
Output   : Error
           not
           installed
Related  : free(), strtok(), Strchrc()
*/

#include <string.h>
#include <stdlib.h>
#ifdef USRLIBHANSOFT
#include <hansoft.h>
#else
#include "hansoft.h"
#endif


#ifndef ARCHAIC
  char **Strtova (char *str, char *delimit)
#else
  char **Strtova (str, delimit) char *str; char *delimit;
#endif

{
  int SIZEp;                           /* No. of initial pointers */
  int x;                               /* counter */
  char **args;                         /* pointer to array of char pointers */

/* Allocate enough memory for all pointers. Return on error */

  if ((args = (char **) calloc ((SIZEp = (Strchrc (str, delimit) + 2)),
                                 sizeof (char *))) == NULL) return (NULL);

/* Tokenize the string, but don't use the last pointer (must be NULL), until
   all the pointers have been allocated to tokens or until the last pointer has
   been used. */

  args [0] = strtok (str, delimit);
  for (x = 1;
      (x < (SIZEp - 1)) && (int) (args [x] = strtok (NULL, delimit));
       x++);
  return (args);
}
