/*
+-------+-----------------+------+-----------------+-------+-----------------+
|Program| TW2C.C          |Module| N/A             |Library| N/A             |
+-------+-----------------+------+-----------------+-------+----------+------+
|HISTORY                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| Turbo C V2.0 version 0.0a                        | HanSoft          |270690|
| Linux V2.2.14 version 1.2b                       | HanSoft          |110602|
| LCC V3.3 version 1.2b                            | HanSoft          |110602|
+--------------------------------------------------+------------------+------+
|MODIFICATION LOG                                  |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
| I/O streamlined, help and /R added               | HanSoft          |301190|
| Renamed program to TW2C; changed /R to -r        | HanSoft          |240992|
| Added fopeneb() support; changed syntax          | HanSoft          |240992|
| Now also removes (most) TW2 control characters   | HanSoft          |240992|
| Fully restructured; added getoptions() and -Cx   | HanSoft          |220993|
| Added ANSI_C support; close files on exit        | HanSoft          |010394|
| Removed EasyC; added Win32 and Linux support     | HanSoft          |110602|
+--------------------------------------------------+------------------+------+
|REMARKS                                           |    Programmer    | Date |
+--------------------------------------------------+------------------+------+
|                                                  |                  |      |
+--------------------------------------------------+------------------+------+

  Copyright (C) 1991,2002 J.L. Bezemer

  This file is part of BDDE

  BDDE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifdef HANSOFT                            /* Do NOT define this! */
#include "hansoft.h"
#else
#include "strdel.c"
#include "strslc.c"
#include "strtrm.c"
#include "strequ.c"
#endif

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

#define LINESIZ 64

#define NONE    0        /* No header */
#define LUNTER  1        /* RS232 header; DOS conversion */
#define GANDLER 2        /* Tape header; Atari conversion */
#define PHAIR   3        /* Tape header; DOS conversion */
#define Z80V2   4        /* Tape header; DOS conversion */

#define HelpScreen "\n\
Spectrum Tasword II converter V1.2b - (c) 1990,2002 by HanSoft\n\
   Usage: TW2C <options> [sourcefile] [destination]\n\n\
Options : -r   (Retains original justification)\n\
          -Cx  (File generated by conversion method %u)"

char RawMode = FALSE;                  /* if TRUE justification is removed */
char SkipBytes = 0;                    /* bytes skipped by fseek() */


#ifndef ARCHAIC
  void help (void)                       /* Prints help and exits */
#else
  void help ()
#endif

{
 puts (HelpScreen);
 exit (EXIT_SUCCESS);
}


#ifndef ARCHAIC
  int getoptions (char **args)           /* get all options */
#else
  int getoptions (args) char **args;
#endif

{
  int x;

  for (x = 1; (args [x]) && (args [x][0] == '-'); x++)
      {
        switch (args [x][1])           /* Interpret and set options */
          {
            case 'r': RawMode = TRUE; break;
            case 'C':
              switch (args [x][2] - '0')
                {
                  case (NONE): break;
                  case (LUNTER): SkipBytes = 9; break;
                  case (GANDLER):
                  case (PHAIR): SkipBytes = 17; break;
                  case (Z80V2): SkipBytes = 24; break;
                  default:
                    puts ("Invalid conversion; aborting");
                    exit (EXIT_FAILURE);
                    break;
                }
                break;
            default : printf ("Illegal option \'%s\' ignored\n", args [x]);
                      break;
          }
       }
  return (x);
}


#ifndef ARCHAIC
  int main (int argc, char **argv)
#else
  int main (argc, argv) int argc; char **argv;
#endif

{
  FILE *InFp;                          /* Tasword II file */
  FILE *OutFp;                         /* converted file */

  char line   [LINESIZ+2];             /* simple line buffer */
  char *p;                             /* temporary pointer to line */

  int  y;                              /* option pointer */
  int  lines;                          /* number of lines converted */
  size_t skip;                         /* number of bytes skipped */


  if ((argc - (y = getoptions (argv))) == 2)
     {
       if ((InFp  = fopen (argv [y], "rb")) == NULL) exit (EXIT_FAILURE);
       if (exists (argv [y + 1]))
         {
           printf ("Output file \'%s\' exists; aborting\n", argv [y + 1]);
           exit (EXIT_FAILURE);
         }
       if ((OutFp = fopen (argv [y + 1], "w")) == NULL) exit (EXIT_FAILURE);
     }
  else help();

  if (fseek (InFp, (long) SkipBytes, SEEK_SET) != 0)
     {
       puts ("fseek() failed; aborting");
       exit (1);
     }
                                       /* read 64 chars of Tasword II file */
  for (
        lines = 0;
        (skip = (fread (line, sizeof (unsigned char), LINESIZ, InFp)))
         == LINESIZ;
        lines++
      )

    {
      line [LINESIZ + 1] = '\0';       /* terminate line */
      for (p = line; *p; p++) if (!isprint ((int) *p)) *p = ' ';
      line [LINESIZ] = '\n';           /* removed CTRL codes and add NL */
      fputs (RawMode ? line : Strequ (line), OutFp);
    }
                                       /* print summary */
  printf
    ("\nSummary: %d lines from \'%s\' converted to \'%s\', %d bytes skipped\n",
    lines, argv [y], argv [y+1], skip);

  fclose (InFp); fclose (OutFp);
  return (EXIT_SUCCESS);
}
